import { system, world } from "@minecraft/server";
import { clearPastEvents } from "./eventDeletion";
const defaultevents = { "7/4": "independence_day", "12/24": "christmas_eve", "12/25": "christmas", "10/31": "halloween", "2/14": "valentines_day", "5/13": "leprechaun_day", "1/1": "new_years", "12/31": "new_years_eve", "2/29": "leap_year", "4/1": "april_fools" };
function numberToOrdinal(number) {
    const lastDigit = number % 10;
    return number + ((number > 3 && number < 21) || lastDigit > 3 || lastDigit == 0 ? "th" : lastDigit == 1 ? "st" : lastDigit == 2 ? "nd" : "rd");
}
let lastUpdatedDay;
system.runInterval(() => {
    const day = world.getDay();
    if (day !== lastUpdatedDay) {
        lastUpdatedDay = day;
        const { date, dayCount } = getInGameDate();
        globalDayInfo = [{ translate: months[date.getUTCMonth()] }, " ", numberToOrdinal(date.getUTCDate()) + ", ", date.getUTCFullYear().toString(), " (", { translate: "hostOption.time.day" }, " " + (dayCount) + ")"];
        world.getAllPlayers().forEach(clearPastEvents);
    }
});
system.afterEvents.scriptEventReceive.subscribe(({ id, message, initiator }) => {
    if (id != "calendars:set_starting_year")
        return;
    try {
        const year = Math.abs(Number.parseInt(message));
        world.setDynamicProperty("startingYear", year === 2000 ? undefined : year);
        lastUpdatedDay = undefined;
    }
    catch (error) {
        if (initiator?.typeId == "minecraft:player")
            initiator.sendMessage("§cStarting year must be an interger!");
    }
});
export const months = ["january", "february", "march", "april", "may", "june", "july", "august", "september", "october", "november", "december"].map(month => "date.full_" + month);
export function getInGameDate() {
    const days = world.getDay() + 1;
    return { dayCount: days, date: new Date(world.getDynamicProperty("startingYear") ?? 2000, 0, days, 0, 0, 0) };
}
export let globalDayInfo;
export const idToDayInfo = new Map();
export function updateDayDisplayInfo(player) {
    if (globalDayInfo === undefined)
        return;
    const { date } = getInGameDate();
    const [month, dayOfMonth, year] = [date.getUTCMonth(), date.getUTCDate(), date.getFullYear()];
    const yearlyeventProperty = inGameDateToDynamicProperty(month, dayOfMonth, undefined, true);
    const defaultEvent = defaultevents[yearlyeventProperty.substring(yearlyeventProperty.indexOf(":") + 1)];
    const eventName = player.getDynamicProperty(inGameDateToDynamicProperty(month, dayOfMonth, year)) ||
        player.getDynamicProperty(yearlyeventProperty) ||
        (defaultEvent ? { translate: "holiday.calendars." + defaultEvent } : undefined);
    if (eventName) {
        const display = globalDayInfo.slice();
        display.push("\n", eventName);
        idToDayInfo.set(player.id, display);
    }
    else
        idToDayInfo.delete(player.id);
}
export function inGameDateToDynamicProperty(month, day, year, yearly = false) {
    return yearly ? `yearly:${month + 1}/${day}` : `event:${month + 1}/${day}/${year}`;
}
