import { ModalFormData, MessageFormData } from "@minecraft/server-ui";
import { inGameDateToDynamicProperty } from "./calendarUpdate";
import { getInGameDate } from "./calendarUpdate";
import { months } from "./calendarUpdate";
import { updateDayDisplayInfo } from "./calendarUpdate";
import { eventInPast } from "./eventDeletion";
function showUIerror(errorTranslationKey, player) {
    new MessageFormData().title({ translate: "gui.error" }).body({ translate: errorTranslationKey }).button1({ translate: "gui.cancel" }).button2({ translate: "gui.retry" }).show(player).then(({ selection }) => {
        if (selection == 1)
            showEventCreationUI(player);
    });
}
export function showEventCreationUI(player) {
    const year = getInGameDate().date.getUTCFullYear();
    new ModalFormData()
        .title({ translate: "ui.calendars.create_event_screen.title" })
        .textField({ translate: "options.name" }, "§bNew Year!", "§e")
        .dropdown({ translate: "options.dev_overrideDateMonth" }, months.map(month => ({ translate: month })))
        .slider({ translate: "options.dev_overrideDateDay" }, 1, 31, 1, 1)
        .slider({ translate: "options.dev_overrideDateYear" }, year, year + 10, 1, year)
        .toggle({ translate: "ui.calendars.yearly" }, true)
        .submitButton({ translate: "createWorldScreen.create" }).show(player).then(({ canceled, formValues }) => {
        if (canceled)
            return;
        const eventName = formValues[0];
        const eventMonth = formValues[1];
        const eventDay = formValues[2];
        const eventYear = formValues[3];
        const eventYearly = formValues[4];
        if (eventName.length < 4) {
            showUIerror("ui.calendars.create_event_error.short_name", player);
            return;
        }
        ;
        if (!eventYearly && eventInPast(eventMonth, eventDay, eventYear)) {
            showUIerror("ui.calendars.create_event_error.past", player);
            return;
        }
        const eventPropertyName = inGameDateToDynamicProperty(eventMonth, eventDay, eventYear, eventYearly);
        if (player.getDynamicProperty(eventPropertyName)) {
            showUIerror("ui.calendars.create_event_error.exists", player);
            return;
        }
        if ((!eventYearly && new Date(eventYear, eventMonth, eventDay).getDate() != eventDay) || (eventYearly && new Date(2000, eventMonth, eventDay).getDate() != eventDay)) {
            showUIerror("ui.calendars.create_event_error.low_day", player);
            return;
        }
        player.setDynamicProperty(eventPropertyName, eventName);
        updateDayDisplayInfo(player);
    });
}
