import { system, world } from "@minecraft/server";
import { ModalFormData } from "@minecraft/server-ui";
import { getInGameDate, idToDayInfo } from "./calendarUpdate";
import { showEventCreationUI } from "./eventCreator";
import { updateDayDisplayInfo } from "./calendarUpdate";
export function showEventDeletionUI(player) {
    clearPastEvents(player);
    const eventDates = player.getDynamicPropertyIds();
    if (eventDates.length == 0) {
        showEventCreationUI(player);
        return;
    }
    const eventNames = eventDates.map(id => player.getDynamicProperty(id));
    new ModalFormData()
        .title({ translate: "ui.calendars.delete_event_screen.title" })
        .dropdown({ translate: "options.name" }, eventNames)
        .submitButton({ translate: "createWorldScreen.delete" })
        .show(player).then(({ canceled, formValues, cancelationReason }) => {
        if (!canceled) {
            player.setDynamicProperty(eventDates[formValues[0]]);
            updateDayDisplayInfo(player);
        }
    });
}
export function clearPastEvents(player) {
    player.getDynamicPropertyIds().forEach(propertyName => {
        if (propertyName.startsWith("yearly:"))
            return;
        const [month, day, year] = propertyName.substring(propertyName.indexOf(":") + 1).split("/").map(string => Number.parseInt(string));
        if (eventInPast(month - 1, day, year))
            player.setDynamicProperty(propertyName);
    });
    updateDayDisplayInfo(player);
}
system.runInterval(() => world.getAllPlayers().forEach(clearPastEvents), 25000);
world.afterEvents.playerSpawn.subscribe(({ player }) => clearPastEvents(player));
world.afterEvents.playerLeave.subscribe(({ playerId }) => idToDayInfo.delete(playerId));
export function eventInPast(eventMonth, eventDay, eventYear) {
    const { date } = getInGameDate();
    const [month, dayOfMonth, year] = [date.getUTCMonth(), date.getUTCDate(), date.getUTCFullYear()];
    return (eventYear < year || (eventYear == year && ((eventMonth < month) || eventMonth == month && eventDay < dayOfMonth)));
}
